#pragma once
#include <functional>

namespace spin
{
    class ToggleAction
    {
    public:
        ToggleAction(std::function<void()> toggledTrueAction, std::function<void()> toggledFalseAction, const bool initialState)
            : toggledTrueAction_(toggledTrueAction), toggledFalseAction_(toggledFalseAction), lastState_(initialState){};

        ~ToggleAction() = default;


        void setStateAndReact(const bool newState)
        {
            if (newState != lastState_)
            {
                if (newState)
                {
                    toggledTrueAction_();
                }
                else
                {
                    toggledFalseAction_();
                }
                lastState_ = newState;
            }
        }

    private:

    std::function<void()> toggledTrueAction_;
    std::function<void()> toggledFalseAction_;
    bool lastState_;

    };

} // namespace spin
